package
Version:
v0.0.0-...-cf612d8
Opens a new window with list of versions in this module.
Published: Oct 29, 2025
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
AtoI conver ip addr to int.
func ExternalV4() (ips []string)
TODO tmp PIP
ExternalV4 ...
func InternalV4() (ipv4 string)
InternalV4 ...
ItoA conver int to ip addr.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.